@@ -66,7 +66,7 @@ Config::Config()
   display_name_character = true;
   display_wind_particles = true;
   transparency = ALPHA;
-   
+
   // video
   tmp.video.width = 800;
   tmp.video.height = 600;
@@ -83,14 +83,13 @@ void Config::Init()
 
   // directories
 #ifndef WIN32
-  data_dir = *GetEnv(Constants::ENV_DATADIR, Constants::DEFAULT_DATADIR);
-  locale_dir = *GetEnv(Constants::ENV_LOCALEDIR, Constants::DEFAULT_LOCALEDIR);
+  data_dir = GetEnv(Constants::ENV_DATADIR, Constants::DEFAULT_DATADIR);
+  locale_dir = GetEnv(Constants::ENV_LOCALEDIR, Constants::DEFAULT_LOCALEDIR);
 #else
   data_dir = "data\\";
   locale_dir = "locale\\";
 #endif
-  std::string dft_font_path = std::string(data_dir + PATH_SEPARATOR + "font" + PATH_SEPARATOR + "DejaVuSans.ttf");
-  ttf_filename = *GetEnv(Constants::ENV_FONT_PATH, dft_font_path);
+  ttf_filename = GetEnv(Constants::ENV_FONT_PATH, Constants::DEFAULT_FONT_PATH);
 
 #ifndef WIN32
   personal_dir = GetHome()+"/.wormux/";
@@ -129,7 +128,7 @@ bool Config::ChargeVraiment()
         << _("Error while loading configuration file: %s") << std::endl
         << e.what() << std::endl;
     return false;
-  } 
+  }
 
   return true;
 }
@@ -138,7 +137,7 @@ bool Config::ChargeVraiment()
 bool Config::ChargeXml(xmlpp::Element *xml)
 {
   xmlpp::Element *elem;
-  
+
   //=== Map ===
   LitDocXml::LitString  (xml, "map", tmp.map_name);
 
@@ -154,10 +153,10 @@ bool Config::ChargeXml(xmlpp::Element *xml)
   if (elem != NULL)
   {
     uint max_fps;
-    if (LitDocXml::LitUint (elem, "max_fps", max_fps)) 
+    if (LitDocXml::LitUint (elem, "max_fps", max_fps))
       AppWormux::GetInstance()->video.SetMaxFps(max_fps);
 
-    LitDocXml::LitBool (elem, "display_wind_particles", display_wind_particles);  
+    LitDocXml::LitBool (elem, "display_wind_particles", display_wind_particles);
     LitDocXml::LitBool (elem, "display_energy_character", display_energy_character);
     LitDocXml::LitBool (elem, "display_name_character", display_name_character);
     LitDocXml::LitInt (elem, "width", tmp.video.width);
@@ -182,8 +181,8 @@ bool Config::ChargeXml(xmlpp::Element *xml)
 void Config::SetKeyboardConfig()
 {
   Clavier * clavier = Clavier::GetInstance();
-  
-  clavier->SetKeyAction(SDLK_LEFT,		ACTION_MOVE_LEFT);		
+
+  clavier->SetKeyAction(SDLK_LEFT,		ACTION_MOVE_LEFT);
   clavier->SetKeyAction(SDLK_RIGHT,	ACTION_MOVE_RIGHT);
   clavier->SetKeyAction(SDLK_UP,			ACTION_UP);
   clavier->SetKeyAction(SDLK_DOWN,	ACTION_DOWN);
@@ -212,7 +211,7 @@ void Config::Apply()
 
   // Charge le mode jeu
   weapons_list.Init();
-  
+
   GameMode::GetInstance()->Load(m_game_mode);
 
   // Son
@@ -220,15 +219,15 @@ void Config::Apply()
   jukebox.ActiveEffects (tmp.sound.effects);
   jukebox.SetFrequency (tmp.sound.frequency);
 
-  // Charge les quipes 
+  // Charge les quipes
   InitSkins();
   teams_list.LoadList();
   if (m_xml_charge)
     teams_list.InitList (tmp.teams);
-   
+
   // Charge les terrains
   lst_terrain.Init();
-  if (m_xml_charge && !tmp.map_name.empty()) 
+  if (m_xml_charge && !tmp.map_name.empty())
     lst_terrain.ChangeTerrainNom (tmp.map_name);
   else
     lst_terrain.ChangeTerrain (0);
@@ -237,7 +236,7 @@ void Config::Apply()
 bool Config::Save()
 {
   std::string rep = personal_dir;
-  
+
   // Create the directory if it doesn't exist
 #ifndef WIN32
    if (mkdir (personal_dir.c_str(), 0750) != 0 && errno != EEXIST)
@@ -245,8 +244,8 @@ bool Config::Save()
   if (_mkdir (personal_dir.c_str()) != 0 && errno != EEXIST)
 #endif
   {
-    std::cerr << "o " 
-      << Format(_("Error while creating directory \"%s\": unable to store configuration file."), 
+    std::cerr << "o "
+      << Format(_("Error while creating directory \"%s\": unable to store configuration file."),
           rep.c_str())
       << std::endl;
     return false;
@@ -284,29 +283,29 @@ bool Config::SauveXml()
   AppWormux * app = AppWormux::GetInstance();
 
   xmlpp::Element *noeud_video = racine -> add_child("video");
-  doc.EcritBalise (noeud_video, "display_wind_particles", ulong2str(display_wind_particles));  
+  doc.EcritBalise (noeud_video, "display_wind_particles", ulong2str(display_wind_particles));
   doc.EcritBalise (noeud_video, "display_energy_character", ulong2str(display_energy_character));
   doc.EcritBalise (noeud_video, "display_name_character", ulong2str(display_name_character));
   doc.EcritBalise (noeud_video, "width", ulong2str(app->video.window.GetWidth()));
   doc.EcritBalise (noeud_video, "height", ulong2str(app->video.window.GetHeight()));
-  doc.EcritBalise (noeud_video, "full_screen", 
-		   ulong2str(static_cast<uint>(app->video.IsFullScreen())) );	  
-  doc.EcritBalise (noeud_video, "max_fps", 
+  doc.EcritBalise (noeud_video, "full_screen",
+		   ulong2str(static_cast<uint>(app->video.IsFullScreen())) );
+  doc.EcritBalise (noeud_video, "max_fps",
           long2str(static_cast<int>(app->video.GetMaxFps())));
 
   if ( transparency == ALPHA )
     doc.EcritBalise (noeud_video, "transparency", "alpha");
   else if ( transparency == COLORKEY )
     doc.EcritBalise (noeud_video, "transparency", "colorkey");
- 
+
   //=== Son ===
   xmlpp::Element *noeud_son = racine -> add_child("sound");
   doc.EcritBalise (noeud_son, "music", ulong2str(jukebox.UseMusic()));
-  doc.EcritBalise (noeud_son, "effects", 
+  doc.EcritBalise (noeud_son, "effects",
 		   ulong2str(jukebox.UseEffects()));
   doc.EcritBalise (noeud_son, "frequency",
 		   ulong2str(jukebox.GetFrequency()));
-   
+
   //=== Mode de jeu ===
   doc.EcritBalise (racine, "game_mode", m_game_mode);
   return doc.Sauve();
@@ -316,16 +315,14 @@ bool Config::SauveXml()
  * Return the value of the environment variable 'name' or
  * 'dft' if not set
  */
-std::string * Config::GetEnv(const std::string & name, const std::string & dft) {
-  std::string * value;
+std::string Config::GetEnv(const std::string & name, const std::string & dft) {
   char * c_value = std::getenv(name.c_str());
-  
+
   if (c_value != NULL) {
-    value = new std::string(c_value);
+    return std::string(c_value);
   } else {
-    value = new std::string(dft);
+    return dft;
   }
-  return value;
 }
 
 std::string Config::GetDataDir() const
@@ -348,7 +345,7 @@ bool Config::GetExterieurMondeVide() const
   return exterieur_monde_vide;
 }
 
-bool Config::GetDisplayEnergyCharacter() const 
+bool Config::GetDisplayEnergyCharacter() const
 {
   return display_energy_character;
 }
