@@ -43,6 +43,7 @@
 #include "../map/maps_list.h"
 #include "../map/wind.h"
 #include "../network/network.h"
+#include "../network/randomsync.h"
 #include "../object/bonus_box.h"
 #include "../object/objects_list.h"
 #include "../object/particle.h"
@@ -54,7 +55,7 @@
 #include "../weapon/weapons_list.h"
 
 
-#define ENABLE_LIMIT_FPS    
+#define ENABLE_LIMIT_FPS
 
 bool game_initialise = false;
 bool game_fin_partie;
@@ -76,24 +77,20 @@ GameLoop::GameLoop()
 
 void GameLoop::InitGameData_NetServer()
 {
-  //        action_handler.NewAction(Action(ACTION_ASK_TEAM));
+  AppWormux * app = AppWormux::GetInstance();
+  app->video.SetWindowCaption( std::string("Wormux ") + Constants::VERSION + " - Server mode");
+
   ActionHandler * action_handler = ActionHandler::GetInstance();
-//  AppWormux * app = AppWormux::GetInstance();
+//  action_handler.NewAction(Action(ACTION_ASK_TEAM));
   do
     {
       action_handler->NewAction(Action(ACTION_ASK_VERSION));
       std::string msg=_("Wait for clients");
       action_handler->ExecActions();
       std::cout << msg << std::endl;
-#ifdef CL
-      police_grand.WriteCenterTop (app->video.GetWidth()/2, app->video.GetHeight()/2, msg);
-      CL_Display::clear(CL_Color::black);
-      CL_Display::flip();
-      CL_System::keep_alive(500);
-#endif
     } while (network.state != Network::NETWORK_SERVER_INIT_GAME);
   std::cout << "Server init game." << std::endl;
-        
+
   std::cout << "o " << _("Load map") << std::endl;
   action_handler->NewAction (ActionString(ACTION_SET_MAP, TerrainActif().name));
   world.Reset();
@@ -103,18 +100,18 @@ void GameLoop::InitGameData_NetServer()
 
   // For cliens : Create teams
   action_handler->NewAction (Action(ACTION_CLEAR_TEAMS));
-  
-  TeamsList::iterator 
+
+  TeamsList::iterator
     it=teams_list.playing_list.begin(),
     end=teams_list.playing_list.end();
 
   for (; it != end; ++it)
     {
       Team& team = **it;
-                
+
       // cliens : Create teams
       action_handler->NewAction (ActionString(ACTION_NEW_TEAM, team.GetId()));
-                
+
       // cliens : Place characters
       action_handler->NewAction (ActionString(ACTION_CHANGE_TEAM, team.GetId()));
       Team::iterator
@@ -127,38 +124,57 @@ void GameLoop::InitGameData_NetServer()
           action_handler->NewAction (ActionInt(
                                               ACTION_CHANGE_CHARACTER, i));
           action_handler->NewAction (ActionInt2(
-                                               ACTION_MOVE_CHARACTER, 
+                                               ACTION_MOVE_CHARACTER,
                                                character.GetX(), character.GetY()));
           action_handler->NewAction (ActionInt(
-                                              ACTION_SET_CHARACTER_DIRECTION, 
+                                              ACTION_SET_CHARACTER_DIRECTION,
                                               character.GetDirection()));
+          action_handler->NewAction (ActionInt(
+                                              ACTION_SET_FRAME,
+                                              (int)character.image->GetCurrentFrame()));
         }
 
       // Select first character
       action_handler->NewAction (ActionInt(ACTION_CHANGE_CHARACTER, 0));
     }
-        
+
   action_handler->NewAction (ActionString(ACTION_CHANGE_TEAM, ActiveTeam().GetId()));
   action_handler->NewAction (ActionInt(ACTION_CHANGE_CHARACTER, ActiveTeam().ActiveCharacterIndex()));
 
   // Create objects
   lst_objects.Init();
    // @@@ TODO : send objects ... @@@@
-        
+
   // Remise  zro
   std::cout << "o " << _("Initialise data") << std::endl;
   CurseurVer::GetInstance()->Reset();
-  Time::GetInstance()->Reset();
   Mouse::GetInstance()->Reset();
   fps.Reset();
   Interface::GetInstance()->Reset();
   GameMessages::GetInstance()->Reset();
-  
+
+  //Set the second team as a team played from the client
+  TeamsList::iterator team = teams_list.playing_list.begin();
+  (*team)->is_local = true;
+  team++;
+  (*team)->is_local = false;
+
+  //Signale les clients que le jeu peut démarrer
   action_handler->NewAction (Action(ACTION_START_GAME));
+  action_handler->ExecActions();
+  network.state = Network::NETWORK_WAIT_CLIENTS;
+  //Attend que le client ait démarré
+  while (network.state != Network::NETWORK_PLAYING)
+  {
+    action_handler->ExecActions();
+    SDL_Delay(200);
+  }
 }
 
 void GameLoop::InitGameData_NetClient()
 {
+  AppWormux * app = AppWormux::GetInstance();
+  app->video.SetWindowCaption( std::string("Wormux ") + Constants::VERSION + " - Client mode");
   ActionHandler * action_handler = ActionHandler::GetInstance();
   do
     {
@@ -182,20 +198,21 @@ void GameLoop::InitGameData_NetClient()
       action_handler->ExecActions();
       std::cout << network.state << std::endl;
       std::cout << msg << std::endl;
-#ifdef CL
-      police_grand.WriteCenterTop (app->video.GetWidth()/2, app->video.GetHeight()/2, msg);
-      CL_Display::clear(CL_Color::black);
-      CL_Display::flip();
-      CL_System::keep_alive(300);
-#endif
+      SDL_Delay(100);
     } while (network.state != Network::NETWORK_PLAYING);
   std::cout << network.state << " : Run game !" << std::endl;
- 
+
   // @@@ TODO @@@
   lst_objects.Init();
- 
+
   //Set the second team as a team played from the client
-  ActiveTeam().is_local = false;
+  TeamsList::iterator team = teams_list.playing_list.begin();
+  (*team)->is_local = false;
+  team++;
+  (*team)->is_local = true;
+
+  //Signal au serveur que la partie démarre
+  action_handler->NewAction (Action(ACTION_START_GAME));
 }
 
 void GameLoop::InitData_Local()
@@ -214,33 +231,35 @@ void GameLoop::InitData_Local()
 void GameLoop::InitData()
 {
   Time::GetInstance()->Reset();
-  
+
   if (network.is_server())
     InitGameData_NetServer();
   else if (network.is_client())
     InitGameData_NetClient();
-  else        
-  InitData_Local();
+  else
+    InitData_Local();
 
+  randomSync.Init();
   CurseurVer::GetInstance()->Reset();
   Mouse::GetInstance()->Reset();
   Clavier::GetInstance()->Reset();
-   
+
   fps.Reset();
   Interface::GetInstance()->Reset();
   GameMessages::GetInstance()->Reset();
+  ParticleEngine::Init();
 }
 
 void GameLoop::Init ()
 {
   // Display loading screen
   Config * config = Config::GetInstance();
-  AppWormux * app = AppWormux::GetInstance();  
-  
+  AppWormux * app = AppWormux::GetInstance();
+
   Sprite * loading_image = new Sprite(Surface((
 			     config->GetDataDir() + PATH_SEPARATOR
 			     + "menu" + PATH_SEPARATOR
-			     + "img" + PATH_SEPARATOR 
+			     + "img" + PATH_SEPARATOR
 			     + "loading.png").c_str()));
   loading_image->cache.EnableLastFrameCache();
   loading_image->ScaleSize(app->video.window.GetWidth(), app->video.window.GetHeight());
@@ -275,26 +294,25 @@ void GameLoop::Init ()
 
   // Load teams' sound profiles
   jukebox.LoadXML("default");
-  FOR_EACH_TEAM(team) 
+  FOR_EACH_TEAM(team)
     if ( (**team).GetSoundProfile() != "default" )
-      jukebox.LoadXML((**team).GetSoundProfile()) ; 
-   
+      jukebox.LoadXML((**team).GetSoundProfile()) ;
+
   // Begin to play !!
   // Music -> sound should be choosed in map.Init and then we just have to call jukebox.PlayMusic()
   if (jukebox.UseMusic()) jukebox.Play ("share", "music/grenouilles", -1);
-   
-  if (!config->GetDisplayWindParticles()) {
-    TerrainActif().wind.nb_sprite = 0;
-  } else {
-    TerrainActif().wind.nb_sprite = TerrainActif().wind.default_nb_sprite;
-  }
 
   Game::GetInstance()->SetEndOfGameStatus( false );
+
+  Mouse::GetInstance()->SetPointer(POINTER_SELECT);
+
+  ActiveTeam().AccessWeapon().Select();
+
   SetState (PLAYING, true);
 }
 
 void GameLoop::Refresh()
-{  
+{
   RefreshClock();
   GameMessages::GetInstance()->Refresh();
   camera.Refresh();
@@ -302,11 +320,11 @@ void GameLoop::Refresh()
   // Mise  jeu des entres (clavier / mouse)
   // Poll and treat events
   SDL_Event event;
-   
-   while( SDL_PollEvent( &event) ) 
-     {      
-        if ( event.type == SDL_QUIT) 
-          {  
+
+   while( SDL_PollEvent( &event) )
+     {
+        if ( event.type == SDL_QUIT)
+          {
              std::cout << "SDL_QUIT received ===> exit TODO" << std::endl;
              Game::GetInstance()->SetEndOfGameStatus( true );
              std::cout << "FIN PARTIE" << std::endl;
@@ -316,20 +334,20 @@ void GameLoop::Refresh()
           {
              Mouse::GetInstance()->TraiteClic( &event);
           }
-        if ( event.type == SDL_KEYDOWN 
+        if ( event.type == SDL_KEYDOWN
         ||   event.type == SDL_KEYUP)
-          {               
+          {
              if (event.type == SDL_KEYUP && event.key.keysym.sym == SDLK_ESCAPE)
              {
                   Game::GetInstance()->SetEndOfGameStatus( true );
                   std::cout << "FIN PARTIE" << std::endl;
                   return;
              }
-             
+
              Clavier::GetInstance()->HandleKeyEvent( &event);
           }
      }
-   
+
   // How many frame by seconds ?
   fps.Refresh();
 
@@ -337,9 +355,8 @@ void GameLoop::Refresh()
 
   if (!Time::GetInstance()->IsGamePaused())
   {
-     
     // Keyboard and mouse refresh
-    if ( 
+    if (
         (interaction_enabled && state != END_TURN)
         || (ActiveTeam().GetWeapon().IsActive() && ActiveTeam().GetWeapon().override_keys) // for driving supertux for example
         )
@@ -347,7 +364,7 @@ void GameLoop::Refresh()
       Mouse::GetInstance()->Refresh();
       Clavier::GetInstance()->Refresh();
     }
-   
+
     ActionHandler::GetInstance()->ExecActions();
     FOR_ALL_CHARACTERS(equipe,ver) ver -> Refresh();
 
@@ -362,15 +379,16 @@ void GameLoop::Refresh()
     lst_objects.Refresh();
     ParticleEngine::Refresh();
     CurseurVer::GetInstance()->Refresh();
+
   }
-  
+
   // Refresh the map
   world.Refresh();
 }
 
 void GameLoop::Draw ()
 {
-  // Draw the sky 
+  // Draw the sky
   StatStart("GameDraw:sky");
   world.DrawSky();
   StatStop("GameDraw:sky");
@@ -380,7 +398,7 @@ void GameLoop::Draw ()
   world.Draw();
   StatStop("GameDraw:world");
 
-  // Draw the characters 
+  // Draw the characters
   StatStart("GameDraw:characters");
   FOR_ALL_CHARACTERS(equipe,ver) {
     if (&(*ver) != &ActiveCharacter()) {
@@ -428,6 +446,9 @@ void GameLoop::Draw ()
 
   // Add one frame to the fps counter ;-)
   fps.AddOneFrame();
+
+  // Draw the mouse pointer
+  Mouse::GetInstance()->Draw();
 }
 
 void GameLoop::CallDraw()
@@ -440,18 +461,18 @@ void GameLoop::CallDraw()
 
 void GameLoop::Run()
 {
-#ifdef ENABLE_LIMIT_FPS   
+#ifdef ENABLE_LIMIT_FPS
   uint sleep_fps=0;
   uint delay=0;
-#endif 
+#endif
 
   // boucle until game is finished
   do
   {
-#ifdef ENABLE_LIMIT_FPS    
+#ifdef ENABLE_LIMIT_FPS
     unsigned int start = SDL_GetTicks();
-#endif    
-     
+#endif
+
     Game::GetInstance()->SetEndOfGameStatus( false );
 
     // one loop
@@ -463,16 +484,17 @@ void GameLoop::Run()
     StatStop("GameLoop:Draw()");
 
     // try to adjust to max Frame by seconds
-#ifdef ENABLE_LIMIT_FPS    
+#ifdef ENABLE_LIMIT_FPS
     delay = SDL_GetTicks()-start;
-     
+
     if (delay < AppWormux::GetInstance()->video.GetSleepMaxFps())
       sleep_fps = AppWormux::GetInstance()->video.GetSleepMaxFps() - delay;
     else
       sleep_fps = 0;
-    SDL_Delay(sleep_fps);
+    if(sleep_fps >= SDL_TIMESLICE)
+      SDL_Delay(sleep_fps);
 #endif
-  } while( !Game::GetInstance()->GetEndOfGameStatus() ); 
+  } while( !Game::GetInstance()->GetEndOfGameStatus() );
 
   ParticleEngine::Stop();
 }
@@ -482,7 +504,7 @@ void GameLoop::RefreshClock()
   Time * global_time = Time::GetInstance();
   if (global_time->IsGamePaused()) return;
 
-  if (1000 < global_time->Read() - pause_seconde) 
+  if (1000 < global_time->Read() - pause_seconde)
     {
       pause_seconde = global_time->Read();
 
@@ -509,13 +531,20 @@ void GameLoop::RefreshClock()
 
       case END_TURN:
         if (duration <= 1) {
-          if (IsAnythingMoving()) break;
 
-          if (Game::GetInstance()->IsGameFinished()) 
+          if (IsAnythingMoving()) {
+	    duration = 1;
+	    // Hack to be sure that nothing is moving since enough time
+	    // it avoids giving hand to another team during the end of an explosion for example
+	    break;
+	  }
+
+          if (Game::GetInstance()->IsGameFinished())
             Game::GetInstance()->SetEndOfGameStatus( true );
-          else { 
+          else if (BonusBox::NewBonusBox())
+	    break;
+	  else {
 	    ActiveTeam().AccessWeapon().Deselect();
-            BonusBox::NewBonusBox(); 
 	    SetState(PLAYING);
             break;
           }
@@ -531,7 +560,7 @@ void GameLoop::SetState(int new_state, bool begin_game)
 {
   ActionHandler * action_handler = ActionHandler::GetInstance();
 
-  // already in good state, nothing to do 
+  // already in good state, nothing to do
   if ((state == new_state) && !begin_game) return;
 
   state = new_state;
@@ -558,29 +587,34 @@ void GameLoop::SetState(int new_state, bool begin_game)
 
     if (network.is_server() || network.is_local())
      wind.ChooseRandomVal();
-    
+
      character_already_chosen = false;
 
     // Prpare un tour pour un ver
     FOR_ALL_LIVING_CHARACTERS(equipe,ver) ver -> PrepareTurn();
 
     // Changement d'quipe
-    assert (!Game::GetInstance()->IsGameFinished());    
-    do
+    assert (!Game::GetInstance()->IsGameFinished());
+
+    if(network.is_local() || network.is_server())
     {
-      teams_list.NextTeam (begin_game);
-      action_handler->ExecActions();
-    } while (ActiveTeam().NbAliveCharacter() == 0);
-    if( game_mode->allow_character_selection==GameMode::CHANGE_ON_END_TURN
-     || game_mode->allow_character_selection==GameMode::BEFORE_FIRST_ACTION_AND_END_TURN)
-    {
-            action_handler->NewAction(ActionInt(ACTION_CHANGE_CHARACTER,
-                                     ActiveTeam().NextCharacterIndex()));
+      do
+      {
+        teams_list.NextTeam (begin_game);
+        action_handler->ExecActions();
+      } while (ActiveTeam().NbAliveCharacter() == 0);
+
+      if( game_mode->allow_character_selection==GameMode::CHANGE_ON_END_TURN
+       || game_mode->allow_character_selection==GameMode::BEFORE_FIRST_ACTION_AND_END_TURN)
+      {
+              action_handler->NewAction(ActionInt(ACTION_CHANGE_CHARACTER,
+                                       ActiveTeam().NextCharacterIndex()));
+      }
     }
 
     action_handler->ExecActions();
 
-    assert (!ActiveCharacter().IsDead());
+//    assert (!ActiveCharacter().IsDead());
     camera.ChangeObjSuivi (&ActiveCharacter(), true, true);
     interaction_enabled = true; // Be sure that we can play !
     break;
@@ -617,7 +651,7 @@ PhysicalObj* GameLoop::GetMovingObject()
   {
     if (!ver -> IsReady() && !ver -> IsGhost())
     {
-      MSG_DEBUG("game.endofturn", "%s is not ready", (*ver).m_name.c_str())
+      MSG_DEBUG("game.endofturn", "%s is not ready", (*ver).GetName().c_str())
       return &(*ver);
     }
   }
@@ -626,7 +660,7 @@ PhysicalObj* GameLoop::GetMovingObject()
   {
     if (!object -> ptr ->IsReady())
     {
-      MSG_DEBUG("game.endofturn", "%s is not ready", object-> ptr ->m_name.c_str())
+      MSG_DEBUG("game.endofturn", "%s is not ready", object-> ptr ->GetName().c_str())
       return object->ptr;
     }
   }
@@ -640,7 +674,7 @@ bool GameLoop::IsAnythingMoving()
   bool object_still_moving = false;
 
   if (ActiveTeam().GetWeapon().IsActive()) object_still_moving = true;
-  
+
   if (!object_still_moving)
   {
     PhysicalObj *obj = GetMovingObject();
@@ -648,7 +682,7 @@ bool GameLoop::IsAnythingMoving()
     {
       camera.ChangeObjSuivi (obj, true, true);
       object_still_moving = true;
-    } 
+    }
   }
 
   return object_still_moving;
@@ -663,42 +697,42 @@ void GameLoop::SignalCharacterDeath (Character *character)
     return;
 
   if (character -> IsDrowned()) {
-    txt = Format(_("%s has fallen in water."), character -> m_name.c_str());
-    
-  } else if (&ActiveCharacter() == character) { // Active Character is dead 
+    txt = Format(_("%s has fallen in water."), character -> GetName().c_str());
+
+  } else if (&ActiveCharacter() == character) { // Active Character is dead
     CurseurVer::GetInstance()->Cache();
 
     // Is this a suicide ?
     if (ActiveTeam().GetWeaponType() == WEAPON_SUICIDE) {
-      txt = Format(_("%s commits suicide !"), character -> m_name.c_str());
-      
+      txt = Format(_("%s commits suicide !"), character -> GetName().c_str());
+
       // Dead in moving ?
     } else if (state == PLAYING) {
       txt = Format(_("%s has fallen off the map!"),
-                   character -> m_name.c_str());
+                   character -> GetName().c_str());
        jukebox.Play(ActiveTeam().GetSoundProfile(), "out");
-       
+
       // Mort en se faisant toucher par son arme / la mort d'un ennemi ?
     } else {
-      txt = Format(_("%s is dead because he is clumsy!"), 
-                   character -> m_name.c_str());
+      txt = Format(_("%s is dead because he is clumsy!"),
+                   character -> GetName().c_str());
     }
   } else if ((!ActiveCharacter().IsDead())
              && (&character -> GetTeam() == &ActiveTeam())) {
     txt = Format(_("%s is a psychopath, he has killed a member of %s team!"),
-                 ActiveCharacter().m_name.c_str(), character -> m_name.c_str());
+                 ActiveCharacter().GetName().c_str(), character -> GetName().c_str());
   } else if (ActiveTeam().GetWeaponType() == WEAPON_GUN) {
     txt = Format(_("What a shame for %s - he was killed by a simple gun!"),
-                 character -> m_name.c_str());
+                 character -> GetName().c_str());
   } else {
     // Affiche la mort du ver
     txt = Format(_("%s (%s team) has died."),
-                 character -> m_name.c_str(), 
+                 character -> GetName().c_str(),
                  character -> GetTeam().GetName().c_str());
   }
-  
+
   GameMessages::GetInstance()->Add (txt);
-  
+
   // Si c'est le ver actif qui est mort, fin du tour
   if (character == &ActiveCharacter()) SetState (END_TURN);
 }
