@@ -45,9 +45,6 @@ public:
   {
     uint nb_sprite;
     uint default_nb_sprite;
-    double particle_wind_factor;
-    double particle_mass; //Mean of the mass(read in the XML file)
-    double particle_air_resist_factor;
     bool need_flip; //do we need to flip the sprite when it changes direction?
   } wind;
 
