@@ -42,6 +42,8 @@ private:
 
   std::multimap<std::string, std::string> m_soundsamples;
 
+  std::map<int, Mix_Chunk*> chunks;
+
   struct s_m_config{
     bool music;
     bool effects;
@@ -53,6 +55,8 @@ private:
 
   std::set<std::string> m_profiles_loaded;
 
+  static void EndChunk(int channel);
+
 public:
   JukeBox();
   void Init();
