@@ -1,6 +1,23 @@
-/*
- * Exemple d'utilisation de la librairie libxml++ version 1.0.
- */
+/******************************************************************************
+ *  Wormux, a free clone of the game Worms from Team17.
+ *  Copyright (C) 2001-2004 Lawrence Azzoug.
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
+ ******************************************************************************
+ * Xml documents access
+ *****************************************************************************/
 
 #include "xml_document.h"
 #include <libxml++/libxml++.h>
@@ -98,17 +115,9 @@ bool LitDocXml::LitBool (const xmlpp::Node *x,
 			 const std::string &nom,
 			 bool &sortie)
 {
-  int val;
-  if (!LitInt(x,nom,val)) return false;
-  if (val == 0) {
-    sortie = false;
-    return true;
-  } else if (val == 1) {
-    sortie = true;
-    return true;
-  } else {
-    return false;
-  }
+  std::string val;
+  if (!LitString(x,nom,val)) return false;
+  return str2bool (val, sortie);
 }
 
 bool LitDocXml::LitValeurBalise (const xmlpp::Node *balise,
