@@ -27,9 +27,9 @@
 #include "../interface/mouse.h"
 #include "../map/map.h"
 #include "../map/camera.h"
+#include "../network/randomsync.h"
 #include "../object/objects_list.h"
 #include "../team/teams_list.h"
-#include "../tool/random.h"
 #include "../tool/i18n.h"
 #include "../weapon/weapon_tools.h"
 
@@ -41,44 +41,44 @@ const uint FORCE_Y_MAX = 40;
 const double OBUS_SPEED = 7 ;
 
 Obus::Obus(AirAttackConfig& cfg) :
-  WeaponProjectile("obus", cfg)
+  WeaponProjectile("air_attack_projectile", cfg)
 {
   is_active = true;
+  explode_colliding_character = true;
   Ready();
 }
 
 void Obus::SignalCollision()
 { 
   is_active = false; 
+  lst_objects.RemoveObject(this);
 
-  if (IsGhost()) return;
+  if (!IsGhost())
+    Explosion();
 }
 
 
 
 //-----------------------------------------------------------------------------
 
-Avion::Avion(AirAttackConfig &p_cfg) : 
-  PhysicalObj("Avion", 0.0),
+Plane::Plane(AirAttackConfig &p_cfg) : 
+  PhysicalObj("air_attack_plane"),
   cfg(p_cfg)
 {
   m_type = objUNBREAKABLE;
-  SetWindFactor(1.0);  
-  SetAirResistFactor(1.0);
-  m_gravity_factor = 0.0;
   m_alive = GHOST;
 
-  image = new Sprite( resource_manager.LoadImage( weapons_res_profile, "air_attack_plane"));
+  image = resource_manager.LoadSprite( weapons_res_profile, "air_attack_plane");
   SetSize(image->GetSize());
-  SetMass (3000);
   obus_dx = 100;
-  obus_dy = 50;
+  obus_dy = GetY()+GetHeight();
 }
 
-void Avion::Shoot(double speed)
-{  
-  obus_laches = false;
-  obus_actifs = false;
+void Plane::Shoot(double speed)
+{
+  nb_dropped_bombs = 0;
+  last_dropped_bomb = NULL;
+
   Point2d speed_vector ;
   int dir = ActiveCharacter().GetDirection();
   cible_x = Mouse::GetInstance()->GetWorldPosition().x;
@@ -106,83 +106,61 @@ void Avion::Shoot(double speed)
   lst_objects.AddObject(this);
 }
 
-void Avion::Refresh()
+void Plane::DropBomb()
 {
-  if (IsGhost()) return;  
-  UpdatePosition();
+  Obus * instance = new Obus(cfg);
+  instance->SetXY( Point2i(GetX(), obus_dy) );
+  
+  Point2d speed_vector;
+  
+  int fx = randomSync.GetLong (FORCE_X_MIN, FORCE_X_MAX);
+  fx *= GetDirection();
+  int fy = randomSync.GetLong (FORCE_Y_MIN, FORCE_Y_MAX);
+  
+  speed_vector.SetValues( fx/30.0, fy/30.0);
+  instance->SetSpeedXY (speed_vector);
+  
+  lst_objects.AddObject(instance);
+  
+  camera.ChangeObjSuivi (instance, true, true);
+  
+  last_dropped_bomb = instance;
+  nb_dropped_bombs++;
+}
 
-  // L'avion est arriv au bon endroit ? Largue les obus
-  if (!obus_laches && PeutLacherObus())
-  {
-    obus_laches = true;
-    obus_actifs = true;
+void Plane::Refresh()
+{
+  if ( ! IsGhost() ) {
+
+    UpdatePosition();
     
-    int x=LitCibleX();
-    Obus * instance;
-
-    for (uint i=0; i<cfg.nbr_obus; ++i) 
-    {
-      instance = new Obus(cfg);
-      instance->SetXY( Point2i(x, obus_dy) );
-
-      Point2d speed_vector;
-
-      int fx = randomObj.GetLong (FORCE_X_MIN, FORCE_X_MAX);
-      fx *= GetDirection();
-      int fy = randomObj.GetLong (FORCE_Y_MIN, FORCE_Y_MAX);
-
-      speed_vector.SetValues( fx/30.0, fy/30.0);
-      instance->SetSpeedXY (speed_vector);
-      obus.push_back (instance);
-      
-      camera.ChangeObjSuivi (instance, true, true);
+    image->Update();
+    
+    // First shoot !!
+    if ( OnTopOfTarget() && nb_dropped_bombs == 0)
+      DropBomb();
+    else if (nb_dropped_bombs > 0 &&  nb_dropped_bombs < cfg.nbr_obus) {
+      // Get the last rocket and check the position to be sure to not collide with it
+      if ( last_dropped_bomb->GetY() > GetY()+GetHeight()+10 )
+	DropBomb();
     }
   }
-
-  obus_actifs = false;
-  iterator it=obus.begin(), end=obus.end();
-
-  while (it != end) {     
-    (*it)->Refresh();
-    (*it)->UpdatePosition();
-
-    if (!(*it)->is_active){
-      (*it)->Explosion();
-      it = obus.erase(it);
-    } else {
-      obus_actifs = true;
-      ++it;
-    }
-  }
-
-  if (!obus_actifs && IsGhost()) {  
-    obus.clear();
-    GameLoop::GetInstance()->interaction_enabled=true;
-  }
 }
 
-int Avion::LitCibleX() const { return cible_x; }
-
-int Avion::GetDirection() const { 
+int Plane::GetDirection() const 
+{ 
   float x,y;
   image->GetScaleFactors(x,y);
   return (x<0)?-1:1;
 }
 
-void Avion::Draw()
+void Plane::Draw()
 {
   if (IsGhost()) return;  
   image->Draw(GetPosition());  
-
-  // Dessine les obus
-  if (obus_actifs)
-  {
-    iterator it=obus.begin(), fin=obus.end();
-    for (; it != fin; ++it) (*it)->Draw ();
-  }
 }
 
-bool Avion::PeutLacherObus() const
+bool Plane::OnTopOfTarget() const
 {
   if (GetDirection() == 1) 
     return (cible_x <= GetX()+obus_dx);
@@ -190,7 +168,7 @@ bool Avion::PeutLacherObus() const
     return (GetX()+(int)image->GetWidth()-obus_dx <= cible_x);
 }
 
-void Avion::SignalGhostState (bool was_dead)
+void Plane::SignalGhostState (bool was_dead)
 {
   lst_objects.RemoveObject(this);
 }
@@ -199,7 +177,7 @@ void Avion::SignalGhostState (bool was_dead)
 
 AirAttack::AirAttack() :
   Weapon(WEAPON_AIR_ATTACK, "air_attack",new AirAttackConfig(), ALWAYS_VISIBLE),
-  avion(cfg())
+  plane(cfg())
 {  
   m_name = _("Air attack");
   can_be_used_on_closed_map = false;
@@ -207,7 +185,7 @@ AirAttack::AirAttack() :
 
 void AirAttack::Refresh()
 {
-  if (!avion.obus_actifs && avion.obus_laches) m_is_active = false;
+  m_is_active = false;
 }
 
 void AirAttack::ChooseTarget()
@@ -217,9 +195,7 @@ void AirAttack::ChooseTarget()
 
 bool AirAttack::p_Shoot ()
 {
-  GameLoop::GetInstance()->interaction_enabled=false;
-  avion.Shoot (cfg().speed);
-  m_is_active = false;
+  plane.Shoot (cfg().speed);
   return true;
 }
 
@@ -240,4 +216,3 @@ void AirAttackConfig::LoadXml(xmlpp::Element *elem)
   LitDocXml::LitUint (elem, "nbr_obus", nbr_obus);
   LitDocXml::LitDouble (elem, "speed", speed);
 }
-
